==> deepin-font-manager_5.8.0.13.orig.tar.xz: deepin-font-manager-5.8.0.13/translations/deepin-font-manager_pt_BR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.1">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>Todas as Fontes</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Usuário</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Favoritos</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Ativo</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>Chinês</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>Monoespaçada</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>Arquivo corrompido</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>A mesma versão já está instalada</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>Fonte do Sistema</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl+Shift+/</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Ctrl+Shift+K</source>
        <translation>Ctrl+Shift+K</translation>
    </message>
    <message>
        <source>Alt+Return</source>
        <translation>Alt+Enter</translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation>Fontes</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>%1 fonte instalada</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>%1 fontes instaladas</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>Are you sure you want to delete this font?</source>
        <translation>Excluir está fonte?</translation>
    </message>
    <message>
        <source>This font will not be available to applications</source>
        <translation>Esta fonte não estará disponível para os aplicativos</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>Estas fontes não estarão disponíveis para os aplicativos</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation>As outras %1 fontes do sistema não podem ser excluídas</translation>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation>A fonte &quot;%1&quot; em uso, não pode ser excluída</translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation>As outras %1 fontes do sistema e a fonte &quot;%2&quot; em uso, não podem ser excluídas</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation>Excluir %1 fonte(s)?</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Excluir</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>Excluindo fontes, aguarde...</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>Verificação da Fonte</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Sair</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>Nenhuma fonte para instalar</translation>
    </message>
</context>
<context>
    <name>Font</name>
    <message>
        <source>Don&apos;t let your dreams be dreams</source>
        <translation>Não deixe seus sonhos serem apenas sonhos</translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>Informações básicas</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Estilo</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versão</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Descrição</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Desconhecido</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>Nome completo</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>Nome do postscript</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>Marca comercial</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>Gerenciador de Fontes</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>O Gerenciador de Fontes facilita a instalação e o gerenciamento fontes.</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>Carregando fontes, aguarde...</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>A fonte foi exportada para a área de trabalho</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>%1 fontes exportadas para a área de trabalho</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>Falha ao exportar 1 fonte. Não há espaço disponível em disco.</translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>Falha ao exportar %1 fontes. Não há espaço disponível em disco.</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>Adicionar fonte</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Ativar</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Desativar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Excluir</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorito</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Remover dos Favoritos</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detalhes</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Exibir no Gerenciador de Arquivos</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportar</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>desativado</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>As fontes foram desativadas</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>% 1 está em uso; portanto não é possível desativá-lo</translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation>Não é possível desativar as fontes do sistema e as fontes em uso</translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation>Não é possível desativar as fontes do sistema</translation>
    </message>
    <message>
        <source>Some fonts are not allowed to be disabled</source>
        <translation>Algumas fontes não podem ser desativadas</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>Instalar Fonte</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>Verificando...</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>Desconhecido</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>Arquivo corrompido</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>Instalado</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>Não instalado</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>Instalar Fonte</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>Pesquisar</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>Nenhum resultado encontrado</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>Nenhuma fonte</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Exibir atalhos</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Página acima</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Página abaixo</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Excluir</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>Adicionar fonte</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorito</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Remover dos Favoritos</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>Informações da fonte</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>Insira o texto de pré-visualização</translation>
    </message>
</context>
<context>
    <name>DFontWidget</name>
    <message>
        <source>Broken file</source>
        <translation>Arquivo corrompido</translation>
    </message>
</context>
</TS>

==> deepin-font-manager_5.9.14.orig.tar.xz: deepin-font-manager-5.9.14/translations/deepin-font-manager_pt_BR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt_BR">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>Todas as Fontes</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Usuário</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Favoritos</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Ativo</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>Chinês</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>Monoespaçada</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>DFDeleteTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be deleted</source>
        <translation>%1 é uma família de fontes; se prosseguir, todas as fontes nela contidas serão excluídas</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Excluir</translation>
    </message>
</context>
<context>
    <name>DFDisableTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be enabled</source>
        <translation>%1 é uma família de fontes: se prosseguir, todas as fontes serão desabilitadas</translation>
    </message>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be disabled</source>
        <translation>%1 é uma família de fontes; se prosseguir, todas as fontes serão desabilitadas</translation>
    </message>
    <message>
        <source>Enable</source>
        <comment>button</comment>
        <translation>Ativar</translation>
    </message>
    <message>
        <source>Disable</source>
        <comment>button</comment>
        <translation>Desativar</translation>
    </message>
</context>
<context>
    <name>DFHandleTTCDialog</name>
    <message>
        <source>Apply to all selected font families</source>
        <translation>Aplicar a todas as famílias de fontes selecionadas</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>Arquivo corrompido</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>A mesma versão já está instalada</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>Fonte do Sistema</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl+Shift+/</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>%1 fonte instalada</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>%1 fontes instaladas</translation>
    </message>
    <message>
        <source>Alt+M</source>
        <translation>Alt + M</translation>
    </message>
    <message>
        <source>CTRL+I</source>
        <translation>CTRL + I</translation>
    </message>
    <message>
        <source>Failed to install %1 font. There is not enough disk space.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to install %1 fonts. There is not enough disk space.</source>
        <translation>Falha ao instalar %1 fontes. Não há espaço disponível em disco.</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>This font will not be available to applications</source>
        <translation>Esta fonte não estará disponível para os aplicativos</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>Estas fontes não estarão disponíveis para os aplicativos</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation>As outras %1 fontes do sistema não podem ser excluídas</translation>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation>A fonte &quot;%1&quot; em uso, não pode ser excluída</translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation>As outras %1 fontes do sistema e a fonte &quot;%2&quot; em uso, não podem ser excluídas</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation>Excluir %1 fonte(s)?</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Excluir</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>Excluindo fontes, aguarde...</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>Verificação da Fonte</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>Nenhuma fonte para instalar</translation>
    </message>
    <message>
        <source>Exit</source>
        <comment>button</comment>
        <translation>Sair</translation>
    </message>
    <message>
        <source>Continue</source>
        <comment>button</comment>
        <translation>Continuar</translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>Informações básicas</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Estilo</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versão</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Descrição</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Desconhecido</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>Nome completo</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>Nome do postscript</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>Marca comercial</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>Gerenciador de Fontes</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>O Gerenciador de Fontes facilita a instalação e o gerenciamento fontes.</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>Carregando fontes, aguarde...</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>A fonte foi exportada para a área de trabalho</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>%1 fontes exportadas para a área de trabalho</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>Falha ao exportar 1 fonte. Não há espaço disponível em disco.</translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>Falha ao exportar %1 fontes. Não há espaço disponível em disco.</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>Adicionar fonte</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Ativar</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Desativar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Excluir</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorito</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Remover dos Favoritos</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detalhes</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Exibir no Gerenciador de Arquivos</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportar</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>desativado</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>As fontes foram desativadas</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>% 1 está em uso; portanto não é possível desativá-lo</translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation>Não é possível desativar as fontes do sistema e as fontes em uso</translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation>Não é possível desativar as fontes do sistema</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>Instalar Fonte</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>Verificando...</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>Desconhecido</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>Arquivo corrompido</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>Instalado</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>Não instalado</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>Instalar Fonte</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>Pesquisar</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>Nenhum resultado encontrado</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>Nenhuma fonte</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Exibir atalhos</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Página acima</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Página abaixo</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Excluir</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>Adicionar fonte</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorito</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Remover dos Favoritos</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>Informações da fonte</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>Insira o texto de pré-visualização</translation>
    </message>
</context>
</TS>
